@@ -90,7 +90,7 @@ class K3SController:
         return succeed
 
     @exception_class_dec(max_try=1)
-    def get_instance_info_by_node_meta(self, region_id: str, node_meta: NodeMetaDO, timeout=300):
+    def get_instance_info_by_node_meta(self, region_id: str, node_meta: NodeMetaDO, timeout=10):
         data = json.dumps(node_meta.dict())
         response=requests.get(f'{self.url}/instance/region_id/{region_id}/node_meta', 
             headers=self.header, data=data, timeout=timeout)
@@ -102,7 +102,7 @@ class K3SController:
         return instance_info, instance_type_info
 
     @exception_class_dec(max_try=1)
-    def get_existing_nodes(self, cluster_name: str, timeout=300):
+    def get_existing_nodes(self, cluster_name: str, timeout=10):
         response=requests.get(f'{self.url}/nodes/cluster_name/{cluster_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
@@ -110,7 +110,7 @@ class K3SController:
         return [NodeInfoDO(**info) for info in infos]
 
     @exception_class_dec(max_try=1)
-    def get_existing_nodes_by_name(self, node_name:str, timeout=300):
+    def get_existing_nodes_by_name(self, node_name:str, timeout=10):
         response=requests.get(f'{self.url}/nodes/node_name/{node_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
@@ -126,8 +126,8 @@ class K3SController:
         return [NodeMetaDO(**meta) for meta in infos]
 
     @exception_class_dec(max_try=1)
-    def add_node_label(self, node_infos: List[NodeInfoDO], key: str, value: str, timeout=30):
-        data = [info.to_json() for info in node_infos]
+    def add_node_label(self, node_infos: List[NodeInfoDO], key: str, value: str, timeout=10):
+        data = [info.dict() for info in node_infos]
         data = json.dumps(data)
         response=requests.post(f'{self.url}/label/key/{key}/value/{value}', 
             headers=self.header, data=data, timeout=timeout)
@@ -136,7 +136,7 @@ class K3SController:
         return infos
 
     @exception_class_dec(max_try=1)
-    def get_namespaces(self, cluster_name: str, timeout=30):
+    def get_namespaces(self, cluster_name: str, timeout=10):
         response=requests.get(f'{self.url}/namespaces/cluster_name/{cluster_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
@@ -147,7 +147,7 @@ class K3SController:
             return [NamespaceDO(**namespace) for namespace in infos]
 
     @exception_class_dec(max_try=1)
-    def create_namespace(self, cluster_name: str, namespace_name: str, timeout=30):
+    def create_namespace(self, cluster_name: str, namespace_name: str, timeout=10):
         response=requests.post(
             f'{self.url}/namespace/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
@@ -172,7 +172,7 @@ class K3SController:
         return info
 
     @exception_class_dec(max_try=1)
-    def get_secrets(self, cluster_name: str, namespace_name: str, timeout=30):
+    def get_secrets(self, cluster_name: str, namespace_name: str, timeout=10):
         response=requests.get(
             f'{self.url}/secrets/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
@@ -188,7 +188,7 @@ class K3SController:
         self, 
         cluster_name: str, 
         config_map_user_settings: List[ConfigMapUserSettingDO],
-        timeout=300
+        timeout=10
     ):
         data = [setting.to_json() for setting in config_map_user_settings]
         data = json.dumps(data)
@@ -200,7 +200,7 @@ class K3SController:
         return info
 
     @exception_class_dec(max_try=1)
-    def get_config_maps(self, cluster_name:str, namespace_name:str, timeout=30):
+    def get_config_maps(self, cluster_name:str, namespace_name:str, timeout=10):
         response=requests.get(
             f'{self.url}/config_maps/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
@@ -236,7 +236,7 @@ class K3SController:
         return info
 
     @exception_class_dec(max_try=1)
-    def get_deployments(self, cluster_name:str, namespace_name:str, timeout=30):
+    def get_deployments(self, cluster_name:str, namespace_name:str, timeout=10):
         response=requests.get(
             f'{self.url}/deployments/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
